PolygonOffsets class

Constructors

PolygonOffsets(Map<int, Offset> allOffsets, [Offset offset = Offset.zero])
const
PolygonOffsets.all(Offset offset)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator *(double t) PolygonOffsets
operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) Offset

Constants

zero → const PolygonOffsets